@@ -1,28 +1,28 @@
 package Jaipo;
+use utf8;
 use warnings;
 use strict;
 use feature qw(:5.10);
 use Jaipo::Config;
 use Jaipo::Notify;
 use Jaipo::Logger;
+use Data::Dumper;
 use base qw/Class::Accessor::Fast/;
 __PACKAGE__->mk_accessors(qw/config/);
 
 use vars qw/$NOTIFY $CONFIG $LOGGER $HANDLER $PUB_SUB @PLUGINS @SERVICES/;
 
+my $debug = 0;
+
 =encoding utf8
 
 =head1 NAME
 
 Jaipo - Micro-blogging Client
 
-=head1 VERSION
-
-Version 0.02
-
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.22';
 
 =head1 DESCRIPTION
 
@@ -51,7 +51,12 @@ sub new {
 	my $class = shift;
 	my %args  = @_;
 	my $self  = {};
-
+	
+    # Jaipo::$_->new($args{$_}) for keys %args;
+	#~ $self{"UI"}		= Jaipo::UI->new( $args{"ui"} );
+	#~ $self{"Notify"}	= Jaipo::Notify->new ( $args{"notify"} );
+	#~ $self{"Service"}	= Jaipo::Service->new ( $args{"service"} );
+	
 	bless $self, $class;
 	return $self;
 }
@@ -205,6 +210,7 @@ sub find_service_by_trigger {
 	$services ||= [ Jaipo->services ];
 	for my $s (@$services) {
 		my $s_tg = $s->trigger_name;
+		print "Service: $s_tg\n";
 		return $s if $s->trigger_name eq $tg;
 	}
 }
@@ -393,8 +399,10 @@ what to do with.
 =cut
 
 sub dispatch_to_service {
+	print "going to dispatch\n";
 	my ( $self, $service_tg, $line ) = @_;
 	my $s = $self->find_service_by_trigger ($service_tg);
+	print "choosen: $s\n";
     my ($sub_command) = ($line =~ m[^(\w+)] );
     $s->dispatch_sub_command( $sub_command , $line );
 
@@ -417,11 +425,14 @@ sub cache_clear {
 sub action {
 	my ( $self, $action, $param ) = @_;
 	my @services = Jaipo->services;
+	print "Services: @services \n" if $debug;
     foreach my $service (@services) {
         if ( UNIVERSAL::can( $service, $action ) ) {
             my $ret = $service->$action($param);
-            use Data::Dumper::Simple;
-            warn Dumper( $ret );
+            if ($debug) {
+				use Data::Dumper::Simple;
+            	warn Dumper( $ret );
+			}
 
             # XXX:
             #  - we should check ret->{type} eq 'notification'
@@ -434,6 +445,7 @@ sub action {
             }
         }
         else {
+		warn "Not a supported action.\n";
             # service plugin doesn't support this kind of action
         }
     }
@@ -442,7 +454,7 @@ sub action {
 
 =head1 AUTHOR
 
-BlueT, C<< <bluet at blue.org> >>
+BlueT - Matthew Lien - 練喆明, C<< <BlueT at BlueT.org> >>
 Cornelius, C<< cornelius.howl at gmail.com >>
 
 =head1 BUGS
@@ -451,17 +463,24 @@ Please report any bugs or feature requests to C<bug-jaipo at rt.cpan.org>, or th
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Jaipo>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+
+
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
-	perldoc Jaipo
+    perldoc Jaipo
+
 
 You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item * our main git repository is located at github.com.
+	L<https://github.com/BlueT/jaipo>
+
+=item * RT: CPAN's request tracker (report bugs here)
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Jaipo>
 
@@ -483,13 +502,47 @@ L<http://search.cpan.org/dist/Jaipo/>
 =head1 ACKNOWLEDGEMENTS
 
 
-=head1 COPYRIGHT & LICENSE
+=head1 LICENSE AND COPYRIGHT
 
-Copyright 2009 , all rights reserved.
+Copyright 2017 BlueT - Matthew Lien - 練喆明.
 
-This program is released under the following license: GPL
+This program is free software; you can redistribute it and/or modify it
+under the terms of the the Artistic License (2.0). You may obtain a
+copy of the full license at:
+
+L<http://www.perlfoundation.org/artistic_license_2_0>
+
+Any use, modification, and distribution of the Standard or Modified
+Versions is governed by this Artistic License. By using, modifying or
+distributing the Package, you accept this license. Do not use, modify,
+or distribute the Package, if you do not accept this license.
+
+If your Modified Version has been derived from a Modified Version made
+by someone other than you, you are nevertheless required to ensure that
+your Modified Version complies with the requirements of this license.
+
+This license does not grant you the right to use any trademark, service
+mark, tradename, or logo of the Copyright Holder.
+
+This license includes the non-exclusive, worldwide, free-of-charge
+patent license to make, have made, use, offer to sell, sell, import and
+otherwise transfer the Package with respect to any patent claims
+licensable by the Copyright Holder that are necessarily infringed by the
+Package. If you institute patent litigation (including a cross-claim or
+counterclaim) against any party alleging that the Package constitutes
+direct or contributory patent infringement, then this Artistic License
+to you shall terminate on the date that such litigation is filed.
+
+Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
+AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
+THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
+YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
+CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
+EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 =cut
 
-1;    # End of Jaipo
+1; # End of Jaipo
